@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for CentOS 4.7's 2.6.9 kernel.
+# This is a kernel build script for CentOS 4.6's 2.6.9 kernel.
 #
 
 die () {
@@ -10,33 +10,33 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.9-78.0.13.EL.src.rpm ]
+if [ ! -r kernel-2.6.9-67.0.15.EL.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/centos/4.7/updates/SRPMS/kernel-2.6.9-78.0.13.EL.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/centos/4.6/updates/SRPMS/kernel-2.6.9-67.0.15.EL.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.9-78.0.13.EL.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.9-67.0.15.EL.src.rpm || die "Can't install source package."
 
 cd /usr/src/redhat/SOURCES/ || die "Can't chdir to /usr/src/redhat/SOURCES/ ."
-if [ ! -r ccs-patch-1.5.5-20090202.tar.gz ]
+if [ ! -r ccs-patch-1.6.2-20080625.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/27219/ccs-patch-1.5.5-20090202.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.2-20080625.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/redhat/SPECS/kernel-2.6.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6.spec	2009-01-15 04:12:34.000000000 +0900
-+++ kernel-2.6.spec	2009-01-16 10:21:40.000000000 +0900
-@@ -27,7 +27,7 @@
+--- kernel-2.6.spec	2008-05-08 23:11:38.000000000 +0900
++++ kernel-2.6.spec	2008-05-11 13:16:28.000000000 +0900
+@@ -30,7 +30,7 @@
  # that the kernel isn't the stock distribution kernel, for example by
  # adding some text to the end of the version number.
  #
--%define release 78.0.13.EL
-+%define release 78.0.13.EL_tomoyo_1.5.5
+-%define release 67.0.15.EL
++%define release 67.0.15.EL_tomoyo_1.6.2
  %define sublevel 9
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
-@@ -140,6 +140,9 @@
+@@ -136,6 +136,9 @@
  # to versions below the minimum
  #
  
@@ -46,7 +46,7 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -176,7 +179,7 @@
+@@ -172,7 +175,7 @@
  %define __find_provides /usr/lib/rpm/redhat/find-kmod-provides.sh
  %define __find_requires %{nil}
  
@@ -55,18 +55,19 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -4658,6 +4661,10 @@
+@@ -3785,6 +3788,11 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.5.5-20090202.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.9-centos-4.7.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.2-20080625.tar.gz
++sed -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -67.0.15.EL/" -- Makefile
++patch -sp1 < patches/ccs-patch-2.6.9-67.0.15.EL.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -4669,6 +4676,9 @@
+@@ -3796,6 +3804,9 @@
  for i in *.config 
  do 
  	mv $i .config 
@@ -77,11 +78,11 @@ patch << "EOF" || die "Can't patch spec file."
  	cp .config configs/$i 
  done
 EOF
-mv kernel-2.6.spec ccs-kernel.spec || die "Can't rename spec file."
+mv kernel-2.6.spec kernel-2.6.9-67.0.15.EL_tomoyo_1.6.2.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
-echo "Edit /tmp/ccs-kernel.spec if needed, and run"
-echo "rpmbuild -bb /tmp/ccs-kernel.spec"
+echo "Edit /tmp/kernel-2.6.9-67.0.15.EL_tomoyo_1.6.2.spec if needed, and run"
+echo "rpmbuild -bb /tmp/kernel-2.6.9-67.0.15.EL_tomoyo_1.6.2.spec"
 echo "to build kernel rpm packages."
 exit 0
