@@ -8,6 +8,14 @@ die () {
     exit 1
 }
 
+# Download TOMOYO Linux patches.
+mkdir -p /usr/src/rpm/SOURCES/
+cd /usr/src/rpm/SOURCES/ || die "Can't chdir to /usr/src/rpm/SOURCES/ ."
+if [ ! -r ccs-patch-1.6.2-20080625.tar.gz ]
+then
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.2-20080625.tar.gz || die "Can't download patch."
+fi
+
 # Install kernel source packages.
 cd /usr/src/ || die "Can't chdir to /usr/src/ ."
 apt-get install fakeroot build-essential || die "Can't install packages."
@@ -16,16 +24,13 @@ apt-get install kernel-patch-debian-2.6.8 || die "Can't install packages."
 apt-get build-dep kernel-image-2.6.8-4-686-smp || die "Can't install packages."
 apt-get source kernel-image-2.6.8-4-686-smp || die "Can't install kernel source."
 
-# Download TOMOYO Linux patches.
-cd kernel-image-2.6.8-i386-2.6.8/ || die "Can't chdir to kernel-image-2.6.8-i386-2.6.8/ ."
-wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.1-20080510.tar.gz || die "Can't download patch."
-
 # Apply patches and create kernel config.
-tar -zxf ccs-patch-1.6.1-20080510.tar.gz ./config.ccs || die "Can't extract patch."
+cd kernel-image-2.6.8-i386-2.6.8/ || die "Can't chdir to kernel-image-2.6.8-i386-2.6.8/ ."
+tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.6.2-20080625.tar.gz ./config.ccs || die "Can't extract patch."
 cat config/686-smp config.ccs > config/686-smp-ccs || die "Can't create config."
 debian/rules flavours=686-smp-ccs || die "Can't run rules."
 cd build-686-smp-ccs/ || die "Can't chdir to build-686-smp-ccs/ ."
-tar -zxf ../ccs-patch-1.6.1-20080510.tar.gz || die "Can't extract patch."
+tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.6.2-20080625.tar.gz || die "Can't extract patch."
 cp -p Makefile Makefile.tmp || die "Can't create backup."
 patch -p1 < patches/ccs-patch-2.6.8-17sarge1.diff || die "Can't apply patch."
 mv -f Makefile.tmp Makefile || die "Can't restore."
